# Adam Community

Adam Community 是一个 Python 工具包，提供了一系列实用工具和功能，用于与 Adam 社区相关的开发工作。

安装依赖：
```bash
make install
```


## 使用方法

安装完成后，您可以在 Python 代码中导入并使用该包：

```python
from adam_community import tool
from adam_community import util

# 使用相关功能
```

## 开发

运行测试：
```bash
make test
```
